Developpements
==============

Roadmap
-------
 * BSplines in 2D
 * NURBS in 3D
 * Computation of basis geometry in 3D primitives, task given to freecad thanks to the binding.
 * Finite elements models with a binding to CodeAster



Release notes
-------------

v0.1
~~~~

 * Documentation
 * Basis and Frames
 * adapt radius in roundedlines
 * various fixes
 
